@@ -41,7 +41,7 @@ def yolo_base(input_shape,
               weight_quantization=0,
               activ_quantization=0,
               input_weight_quantization=None):
-    """" Instantiates the YOLOv2 architecture.
+    """ Instantiates the YOLOv2 architecture.
 
     Args:
         input_shape (tuple): input shape tuple
@@ -121,7 +121,7 @@ def yolo_base(input_shape,
     x = separable_conv_block(x,
                              filters=(nb_box * (4 + 1 + classes)),
                              name='detection_layer',
-                             kernel_size=(1, 1),
+                             kernel_size=(3, 3),
                              padding='same',
                              use_bias=True,
                              activ_quantization=None,
