@@ -80,15 +80,17 @@ def _skip_ascii_header(file, version):
         int: End of header bytes position.
     """
     bytes_pos = 0  # bytes position
+    line = file.readline()
+    bytes_pos += len(line)
     if version == 2 or version == 3:
-        line = file.readline()
-        bytes_pos += len(line)
         while line.startswith(b'#'):
             if line == b'#!END-HEADER\r\n':
                 break
             else:
                 line = file.readline()
                 bytes_pos += len(line)
+    elif version == 4:
+        return bytes_pos
     else:
         raise ValueError("Unsupported version: %d" % version)
     return bytes_pos
@@ -238,11 +240,13 @@ def _read_aedat_v4(datafile):
     events = []
 
     with AedatFile(datafile) as f:
-        height, width = f['events'].size
-        # loop through the "events" stream
-        for e in f['events']:
-            ev_times.append(e.timestamp)
-            events.append((e.x, e.y, e.polarity))
+        np_events = np.hstack([packet for packet in f['events'].numpy()])
+
+        # access information of all events by type
+        timestamps, x, y, polarities = np_events['timestamp'], np_events[
+            'x'], np_events['y'], np_events['polarity']
+        ev_times = timestamps.tolist()
+        events = np.column_stack((x, y, polarities)).tolist()
 
     return events, ev_times
 
@@ -312,7 +316,7 @@ def get_gesture_data(dataset_name, datafile, labelfile=None):
                 'label': label,
                 'subject': subj,
                 'lighting': lighting_condition,
-                'events': np.array(events, dtype=np.uint8),
+                'events': np.array(events, dtype=np.uint16),
                 'ev_times': np.array(ev_times) - ev_times[0]
             }
         else:
