@@ -67,10 +67,10 @@ from tensorflow.keras.layers import (Input, BatchNormalization, MaxPool2D,
                                      Activation)
 
 # cnn2snn Imports
-from cnn2snn import load_quantized_model
+from cnn2snn import load_quantized_model, quantize
 
 # Local utils
-from ..quantization_blocks import conv_block, separable_conv_block
+from ..layer_blocks import conv_block, separable_conv_block
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/mobilenet/'
 
@@ -149,8 +149,7 @@ def mobilenet_imagenet(input_shape=None,
         dropout (float): dropout rate
         include_top (bool): whether to include the fully-connected
             layer at the top of the model.
-        weights (str): one of `None` (random initialization), 'imagenet' for
-             pretrained weights or the path to the weights file to be loaded.
+        weights (str): the path to the weights file to be loaded.
         pooling (str): Optional pooling mode for feature extraction
             when `include_top` is `False`.
 
@@ -217,9 +216,9 @@ def mobilenet_imagenet(input_shape=None,
                    kernel_size=(3, 3),
                    padding='same',
                    use_bias=False,
-                   activ_quantization=activ_quantization,
-                   weight_quantization=input_weight_quantization,
-                   add_batchnorm=True)
+                   strides=2,
+                   add_batchnorm=True,
+                   add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(64 * alpha),
@@ -227,9 +226,8 @@ def mobilenet_imagenet(input_shape=None,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(128 * alpha),
@@ -238,9 +236,8 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              pooling='max',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(128 * alpha),
@@ -248,9 +245,8 @@ def mobilenet_imagenet(input_shape=None,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(256 * alpha),
@@ -259,9 +255,8 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              pooling='max',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(256 * alpha),
@@ -269,9 +264,9 @@ def mobilenet_imagenet(input_shape=None,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
+
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
                              name='separable_6',
@@ -279,9 +274,8 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              pooling='max',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
@@ -289,9 +283,8 @@ def mobilenet_imagenet(input_shape=None,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
@@ -299,9 +292,8 @@ def mobilenet_imagenet(input_shape=None,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
@@ -309,9 +301,8 @@ def mobilenet_imagenet(input_shape=None,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
@@ -319,9 +310,8 @@ def mobilenet_imagenet(input_shape=None,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(512 * alpha),
@@ -329,9 +319,8 @@ def mobilenet_imagenet(input_shape=None,
                              kernel_size=(3, 3),
                              padding='same',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     x = separable_conv_block(x,
                              filters=int(1024 * alpha),
@@ -340,9 +329,8 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              pooling='max',
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     # Last separable layer with global pooling
     layer_pooling = 'global_avg' if include_top or pooling == 'avg' else None
@@ -353,9 +341,8 @@ def mobilenet_imagenet(input_shape=None,
                              padding='same',
                              pooling=layer_pooling,
                              use_bias=False,
-                             activ_quantization=activ_quantization,
-                             weight_quantization=weight_quantization,
-                             add_batchnorm=True)
+                             add_batchnorm=True,
+                             add_activation=True)
 
     if include_top:
         shape = (1, 1, int(1024 * alpha))
@@ -369,20 +356,26 @@ def mobilenet_imagenet(input_shape=None,
                                  kernel_size=(3, 3),
                                  padding='same',
                                  use_bias=False,
-                                 activ_quantization=None,
-                                 weight_quantization=weight_quantization,
-                                 add_batchnorm=False)
+                                 add_batchnorm=False,
+                                 add_activation=False)
         x = Activation('softmax', name='act_softmax')(x)
         x = Reshape((classes,), name='reshape_2')(x)
 
     # Create model.
-    model = Model(img_input, x, name='mobilenet_%0.2f_%s' % (alpha, rows))
+    model = Model(img_input,
+                  x,
+                  name='mobilenet_%0.2f_%s_%s' % (alpha, rows, classes))
 
     # Load weights
     if weights is not None:
         model.load_weights(weights, by_name=True)
 
-    return model
+    if ((weight_quantization != 0) or (activ_quantization != 0) or
+        (input_weight_quantization != 0)):
+        return quantize(model, weight_quantization, activ_quantization,
+                        input_weight_quantization)
+    else:
+        return model
 
 
 def mobilenet_imagenet_pretrained():
@@ -394,7 +387,7 @@ def mobilenet_imagenet_pretrained():
         tf.keras.Model: a Keras Model instance.
 
     """
-    model_name = 'mobilenet_imagenet_wq4_aq4.h5'
+    model_name = 'mobilenet_imagenet_iq8_wq4_aq4.h5'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           cache_subdir='models')
