@@ -126,7 +126,7 @@ def main():
     parser.add_argument("-laq",
                         "--last_activ_quantization",
                         type=int,
-                        default=0,
+                        default=None,
                         help="The last layer activation quantization")
     parser.add_argument("-e",
                         "--epochs",
@@ -152,7 +152,10 @@ def main():
     # If specified, change the last layer activation bitwidth
     if args.last_activ_quantization:
         bitwidth = args.last_activ_quantization
-        model.get_layer('separable_6').bitwidth = bitwidth
+        layer_names = [layer.name for layer in model.layers]
+        layer_idx = layer_names.index('separable_6')
+        last_act_layer = model.layers[layer_idx + 1]
+        last_act_layer.bitwidth = bitwidth
 
     # Prepare the dataset
     x_train, y_train, x_val, y_val = get_rescaled_dataset(a, b)
