@@ -180,27 +180,24 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
 
     # Change the last layer activation bitwidth
     if last_layer_activ_quantization != activ_quantization:
-        model.get_layer('separable_6').bitwidth = last_layer_activ_quantization
+        layer_names = [layer.name for layer in model.layers]
+        layer_idx = layer_names.index('separable_6')
+        last_act_layer = model.layers[layer_idx + 1]
+        last_act_layer.bitwidth = last_layer_activ_quantization
+
     return model
 
 
-def ds_cnn_kws_pretrained(include_top=True):
+def ds_cnn_kws_pretrained():
     """
     Helper method to retrieve a `ds_cnn_kws` model that was trained on
     KWS dataset.
 
-    Args:
-        include_top (bool): optional, whether to include the fully-connected
-         layer at the top of the model.
-
     Returns:
         tf.keras.Model: a Keras Model instance.
 
     """
-    if include_top:
-        model_name = 'ds_cnn_kws_wq4_aq4.hdf5'
-    else:
-        model_name = 'ds_cnn_kws_wq4_aq4_no_top.hdf5'
+    model_name = 'ds_cnn_kws_iq8_wq4_aq4_laq1.h5'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           cache_subdir='models')
