@@ -22,14 +22,14 @@ from tensorflow.keras.layers import Dropout, Flatten, Input
 from tensorflow.keras.utils import get_file
 
 # CNN2SNN imports
-from cnn2snn import load_quantized_model
+from cnn2snn import load_quantized_model, quantize
 
-from ..quantization_blocks import conv_block, dense_block
+from ..layer_blocks import conv_block, dense_block
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/vgg/'
 
 
-def vgg_utk_face(input_shape,
+def vgg_utk_face(input_shape=(32, 32, 3),
                  weights=None,
                  weight_quantization=0,
                  activ_quantization=0,
@@ -74,8 +74,7 @@ def vgg_utk_face(input_shape,
                    name='conv_0',
                    use_bias=False,
                    add_batchnorm=True,
-                   weight_quantization=input_weight_quantization,
-                   activ_quantization=activ_quantization)
+                   add_activation=True)
 
     x = conv_block(x,
                    filters=32,
@@ -86,8 +85,7 @@ def vgg_utk_face(input_shape,
                    pool_size=2,
                    use_bias=False,
                    add_batchnorm=True,
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization)
+                   add_activation=True)
 
     x = Dropout(0.3)(x)
 
@@ -98,8 +96,7 @@ def vgg_utk_face(input_shape,
                    name='conv_2',
                    use_bias=False,
                    add_batchnorm=True,
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization)
+                   add_activation=True)
 
     x = conv_block(x,
                    filters=64,
@@ -110,8 +107,7 @@ def vgg_utk_face(input_shape,
                    pool_size=2,
                    use_bias=False,
                    add_batchnorm=True,
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization)
+                   add_activation=True)
 
     x = Dropout(0.3)(x)
 
@@ -122,8 +118,7 @@ def vgg_utk_face(input_shape,
                    name='conv_4',
                    use_bias=False,
                    add_batchnorm=True,
-                   weight_quantization=weight_quantization,
-                   activ_quantization=activ_quantization)
+                   add_activation=True)
 
     x = Dropout(0.3)(x)
     x = Flatten()(x)
@@ -133,14 +128,9 @@ def vgg_utk_face(input_shape,
                     name='dense_1',
                     use_bias=False,
                     add_batchnorm=True,
-                    weight_quantization=weight_quantization,
-                    activ_quantization=activ_quantization)
+                    add_activation=True)
 
-    x = dense_block(x,
-                    units=1,
-                    name='dense_2',
-                    weight_quantization=weight_quantization,
-                    activ_quantization=None)
+    x = dense_block(x, units=1, name='dense_2', add_activation=False)
 
     model = Model(img_input, x, name='vgg_utk_face')
 
@@ -148,11 +138,24 @@ def vgg_utk_face(input_shape,
     if weights is not None:
         model.load_weights(weights, by_name=True)
 
-    return model
+    if ((weight_quantization != 0) or (activ_quantization != 0) or
+        (input_weight_quantization != 0)):
+        return quantize(model, weight_quantization, activ_quantization,
+                        input_weight_quantization)
+    else:
+        return model
 
 
 def vgg_utk_face_pretrained():
-    model_name = 'vgg_utk_face_wq2_aq2_iq8.hdf5'
+    """
+    Helper method to retrieve a `vgg_utk_face` model that was trained on
+    UTK Face dataset.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'vgg_utk_face_iq8_wq2_aq2.h5'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
                           cache_subdir='models')
